%STARTCUBICBEZ  Start Cubic Bezier Curve
% Generates the first two control points of a cubic Bezier curve and stores
% them in the control point matrix CP
%
% Syntax:  CP = startCubicBez(P, vel)
%
% Inputs:
%    P - position of the first control point
%    vel - vector giving the desired velocity (dr/dt) at the start of the curve
%
% Outputs:
%    CP - control point matrix
%
% See also: GOTHROUGH, STOPCUBICBEZ

% Author: Travis Hydzik
% Last revision: 19 October 2004

function CP = startCubicBez(P, vel)

    CP = [ P
           P + vel/3 ];